/* $Id: proctime.h,v 1.15 1999/02/23 11:43:12 martin Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __GLIBTOP_PROCTIME_H__
#define __GLIBTOP_PROCTIME_H__

#include <glibtop.h>
#include <glibtop/cpu.h>
#include <glibtop/global.h>

BEGIN_LIBGTOP_DECLS

#define GLIBTOP_PROC_TIME_START_TIME	0
#define GLIBTOP_PROC_TIME_RTIME		1
#define GLIBTOP_PROC_TIME_UTIME		2
#define GLIBTOP_PROC_TIME_STIME		3
#define GLIBTOP_PROC_TIME_CUTIME	4
#define GLIBTOP_PROC_TIME_CSTIME	5
#define GLIBTOP_PROC_TIME_TIMEOUT	6
#define GLIBTOP_PROC_TIME_IT_REAL_VALUE	7
#define GLIBTOP_PROC_TIME_FREQUENCY	8
#define GLIBTOP_PROC_TIME_XCPU_UTIME	9
#define GLIBTOP_PROC_TIME_XCPU_STIME	10

#define GLIBTOP_MAX_PROC_TIME		11

typedef struct _glibtop_proc_time	glibtop_proc_time;

/* Time section */

struct _glibtop_proc_time
{
	u_int64_t	flags,
		start_time,	/* start time of process -- 
				 * seconds since 1-1-70 */
		rtime,		/* real time accumulated by process */
		utime,		/* user-mode CPU time accumulated by process */
		stime,		/* kernel-mode CPU time accumulated by process */
		cutime,		/* cumulative utime of process and 
				 * reaped children */
		cstime,		/* cumulative stime of process and 
				 * reaped children */
		timeout,	/* The time (in jiffies) of the process's
				 * next timeout */
		it_real_value,	/* The time (in jiffies) before the
				 * next SIGALRM is sent to the process
				 * due to an interval timer. */
		frequency,	/* Tick frequency. */
		xcpu_utime [GLIBTOP_NCPU],	/* utime and stime for all CPUs on */
		xcpu_stime [GLIBTOP_NCPU];	/* SMP machines. */
};

#define glibtop_get_proc_time(p1, p2)	glibtop_get_proc_time_l(glibtop_global_server, p1, p2)

#if GLIBTOP_SUID_PROC_TIME
#define glibtop_get_proc_time_r	glibtop_get_proc_time_p
#else
#define glibtop_get_proc_time_r	glibtop_get_proc_time_s
#endif

void glibtop_get_proc_time_l (glibtop *server, glibtop_proc_time *buf, pid_t pid);

#if GLIBTOP_SUID_PROC_TIME
void glibtop_init_proc_time_p (glibtop *server);
void glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf, pid_t pid);
#else
void glibtop_init_proc_time_s (glibtop *server);
void glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid);
#endif

#ifdef GLIBTOP_NAMES

/* You need to link with -lgtop_names to get this stuff here. */

extern const char *glibtop_names_proc_time [];
extern const unsigned glibtop_types_proc_time [];
extern const char *glibtop_labels_proc_time [];
extern const char *glibtop_descriptions_proc_time [];

#endif

END_LIBGTOP_DECLS

#endif
