( cd usr/lib ; rm -rf libgnomesupport-2.0.so )
( cd usr/lib ; ln -sf libgnomesupport-2.0.so.0.0.0 libgnomesupport-2.0.so )
( cd usr/lib ; rm -rf libgnomesupport-2.0.so.0 )
( cd usr/lib ; ln -sf libgnomesupport-2.0.so.0.0.0 libgnomesupport-2.0.so.0 )
( cd usr/lib ; rm -rf libgtop-2.0.so )
( cd usr/lib ; ln -sf libgtop-2.0.so.0.0.1 libgtop-2.0.so )
( cd usr/lib ; rm -rf libgtop-2.0.so.0 )
( cd usr/lib ; ln -sf libgtop-2.0.so.0.0.1 libgtop-2.0.so.0 )
( cd usr/lib ; rm -rf libgtop_common-2.0.so )
( cd usr/lib ; ln -sf libgtop_common-2.0.so.0.0.1 libgtop_common-2.0.so )
( cd usr/lib ; rm -rf libgtop_common-2.0.so.0 )
( cd usr/lib ; ln -sf libgtop_common-2.0.so.0.0.1 libgtop_common-2.0.so.0 )
( cd usr/lib ; rm -rf libgtop_names-2.0.so )
( cd usr/lib ; ln -sf libgtop_names-2.0.so.0.0.1 libgtop_names-2.0.so )
( cd usr/lib ; rm -rf libgtop_names-2.0.so.0 )
( cd usr/lib ; ln -sf libgtop_names-2.0.so.0.0.1 libgtop_names-2.0.so.0 )
( cd usr/lib ; rm -rf libgtop_suid_common-2.0.so )
( cd usr/lib ; ln -sf libgtop_suid_common-2.0.so.0.0.1 libgtop_suid_common-2.0.so )
( cd usr/lib ; rm -rf libgtop_suid_common-2.0.so.0 )
( cd usr/lib ; ln -sf libgtop_suid_common-2.0.so.0.0.1 libgtop_suid_common-2.0.so.0 )
( cd usr/lib ; rm -rf libgtop_sysdeps-2.0.so )
( cd usr/lib ; ln -sf libgtop_sysdeps-2.0.so.0.0.1 libgtop_sysdeps-2.0.so )
( cd usr/lib ; rm -rf libgtop_sysdeps-2.0.so.0 )
( cd usr/lib ; ln -sf libgtop_sysdeps-2.0.so.0.0.1 libgtop_sysdeps-2.0.so.0 )
