/* gnomesupport.h */
/* This is a generated file.  Please modify `gnomesupport.awk' */

#ifndef GNOMESUPPORT_H
#define GNOMESUPPORT_H

#include <stddef.h>		/* for size_t */

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* GNOMESUPPORT_H */
